==> virtuoso-opensource-7.1.0.tar.gz: virtuoso-opensource-7.1.0/binsrc/tests/suite/prolog.sh <==
#!/bin/sh
#
#  $Id: prolog.sh,v 1.1.2.4 2013/01/02 16:14:52 source Exp $
#
#  Call all tests in succession
#  
#  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
#  project.
#  
#  Copyright (C) 1998-2014 OpenLink Software
#  
#  This project is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; only version 2 of the License, dated June 1991.
#  
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#  General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#  
#  

# **********************************************************************************
# **********************************************************************************
# **********************************************************************************

ECHO ""
ECHO "THIS TAKES AT LEAST 350 MEGABYTES OF DISK SPACE AND SOME AMOUNT"
ECHO "OF TIME (could be hours). BE PATIENT."
ECHO "use ./summary.sh to display current state of tests being run and test results."

BANNER "STARTED TESTSUITE"

#
#  Setup the environment for the rest of the testsuite
#
rm -f audit.txt core debug.txt

. release.sh

==> virtuoso-opensource-7.2.6.tar.gz: virtuoso-opensource-7.2.6/binsrc/tests/suite/prolog.sh <==
#!/bin/sh
#
#  $Id: prolog.sh,v 1.1.2.4 2013/01/02 16:14:52 source Exp $
#
#  Call all tests in succession
#  
#  This file is part of the OpenLink Software Virtuoso Open-Source (VOS)
#  project.
#  
#  Copyright (C) 1998-2021 OpenLink Software
#  
#  This project is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License as published by the
#  Free Software Foundation; only version 2 of the License, dated June 1991.
#  
#  This program is distributed in the hope that it will be useful, but
#  WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#  General Public License for more details.
#  
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#  
#  

# **********************************************************************************
# **********************************************************************************
# **********************************************************************************

ECHO ""
ECHO "THIS TAKES AT LEAST 3 GIGABYTE OF DISK SPACE AND SOME AMOUNT"
ECHO "OF TIME (could be hours). BE PATIENT."
ECHO "use ./summary.sh to display current state of tests being run and test results."

BANNER "STARTED TESTSUITE"

#
#  Setup the environment for the rest of the testsuite
#
rm -f audit.txt core debug.txt

. release.sh
